@@ -28,7 +28,7 @@ abstract class AdminFormRequest extends FormRequest
      * Return only the fields that we are interested in from the request.
      * This will include empty fields as a null value.
      */
-    public function normalize(array $only = null): array
+    public function normalize(?array $only = null): array
     {
         return $this->only($only ?? array_keys($this->rules()));
     }
