@@ -9,7 +9,7 @@ class AddServerDescriptionColumn extends Migration
     /**
      * Run the migrations.
      */
-    public function up()
+    public function up(): void
     {
         Schema::table('servers', function (Blueprint $table) {
             $table->text('description')->after('name');
@@ -19,7 +19,7 @@ class AddServerDescriptionColumn extends Migration
     /**
      * Reverse the migrations.
      */
-    public function down()
+    public function down(): void
     {
         Schema::table('servers', function (Blueprint $table) {
             $table->dropColumn('description');
