@@ -10,7 +10,7 @@ class UpgradeTaskSystem extends Migration
     /**
      * Run the migrations.
      */
-    public function up()
+    public function up(): void
     {
         Schema::table('tasks', function (Blueprint $table) {
             $table->dropForeign(['server']);
@@ -33,11 +33,11 @@ class UpgradeTaskSystem extends Migration
     /**
      * Reverse the migrations.
      */
-    public function down()
+    public function down(): void
     {
         Schema::table('tasks', function (Blueprint $table) {
-//            $table->dropForeign(['server_id']);
-//            $table->dropForeign(['user_id']);
+            //            $table->dropForeign(['server_id']);
+            //            $table->dropForeign(['user_id']);
 
             $table->renameColumn('server_id', 'server');
             $table->dropColumn('user_id');
