@@ -9,7 +9,7 @@ class CreateDaemonKeysTable extends Migration
     /**
      * Run the migrations.
      */
-    public function up()
+    public function up(): void
     {
         Schema::create('daemon_keys', function (Blueprint $table) {
             $table->increments('id');
@@ -28,7 +28,7 @@ class CreateDaemonKeysTable extends Migration
     /**
      * Reverse the migrations.
      */
-    public function down()
+    public function down(): void
     {
         Schema::dropIfExists('daemon_keys');
     }
