@@ -9,27 +9,21 @@ class AddArchivedFieldToServerTransfersTable extends Migration
 {
     /**
      * Run the migrations.
-     *
-     * @return void
      */
-    public function up()
+    public function up(): void
     {
         Schema::table('server_transfers', function (Blueprint $table) {
             $table->boolean('archived')->default(0)->after('new_additional_allocations');
         });
 
         // Update archived to all be true on existing transfers.
-        Schema::table('server_transfers', function (Blueprint $table) {
-            DB::statement('UPDATE `server_transfers` SET `archived` = 1 WHERE `successful` = 1');
-        });
+        DB::table('server_transfers')->where('successful', true)->update(['archived' => 1]);
     }
 
     /**
      * Reverse the migrations.
-     *
-     * @return void
      */
-    public function down()
+    public function down(): void
     {
         Schema::table('server_transfers', function (Blueprint $table) {
             $table->dropColumn('archived');
