@@ -7,10 +7,8 @@ use Illuminate\Database\Migrations\Migration;
 return new class () extends Migration {
     /**
      * Run the migrations.
-     *
-     * @return void
      */
-    public function up()
+    public function up(): void
     {
         Schema::table('activity_logs', function (Blueprint $table) {
             $table->unsignedInteger('api_key_id')->nullable()->after('actor_id');
@@ -19,10 +17,8 @@ return new class () extends Migration {
 
     /**
      * Reverse the migrations.
-     *
-     * @return void
      */
-    public function down()
+    public function down(): void
     {
         Schema::table('activity_logs', function (Blueprint $table) {
             $table->dropColumn('api_key_id');
